packet-dcerpc: nca_s_fault_sec_pkg_error
[metze/wireshark/wip.git] / file.h
diff --git a/file.h b/file.h
index 79df1cfd68c33754e3390ff2993cd32ee3f31869..65354e7d473ab9953395d45c0b345082d0cf1871 100644 (file)
--- a/file.h
+++ b/file.h
@@ -42,7 +42,7 @@ typedef enum {
 
 /** Return values from functions that read capture files. */
 typedef enum {
-    CF_READ_OK,             /**< operation succeeded */
+    CF_READ_OK,      /**< operation succeeded */
     CF_READ_ERROR,   /**< operation got an error (function may provide err with details) */
     CF_READ_ABORTED  /**< operation aborted by user */
 } cf_read_status_t;
@@ -56,9 +56,9 @@ typedef enum {
 
 /** Return values from functions that print sets of packets. */
 typedef enum {
-       CF_PRINT_OK,            /**< print operation succeeded */
-       CF_PRINT_OPEN_ERROR,    /**< print operation failed while opening printer */
-       CF_PRINT_WRITE_ERROR    /**< print operation failed while writing to the printer */
+    CF_PRINT_OK,            /**< print operation succeeded */
+    CF_PRINT_OPEN_ERROR,    /**< print operation failed while opening printer */
+    CF_PRINT_WRITE_ERROR    /**< print operation failed while writing to the printer */
 } cf_print_status_t;
 
 typedef enum {
@@ -71,18 +71,20 @@ typedef enum {
     cf_cb_file_reload_finished,
     cf_cb_file_rescan_started,
     cf_cb_file_rescan_finished,
-    cf_cb_file_fast_save_finished,
-    cf_cb_packet_selected,
-    cf_cb_packet_unselected,
-    cf_cb_field_unselected,
+    cf_cb_file_retap_started,
+    cf_cb_file_retap_finished,
+    cf_cb_file_fast_save_finished, /* GTK+ only? */
+    cf_cb_packet_selected, /* GTK+ only. */
+    cf_cb_packet_unselected, /* GTK+ only. */
+    cf_cb_field_unselected, /* GTK+ only. */
     cf_cb_file_save_started,
     cf_cb_file_save_finished,
     cf_cb_file_save_failed,
     cf_cb_file_save_stopped,
-    cf_cb_file_export_specified_packets_started,
-    cf_cb_file_export_specified_packets_finished,
-    cf_cb_file_export_specified_packets_failed,
-    cf_cb_file_export_specified_packets_stopped
+    cf_cb_file_export_specified_packets_started, /* GTK+ only. */
+    cf_cb_file_export_specified_packets_finished, /* GTK+ only. */
+    cf_cb_file_export_specified_packets_failed, /* GTK+ only. */
+    cf_cb_file_export_specified_packets_stopped /* GTK+ only. */
 } cf_cbs;
 
 typedef void (*cf_callback_t) (gint event, gpointer data, gpointer user_data);
@@ -95,11 +97,29 @@ typedef struct {
     field_info    *finfo;
 } match_data;
 
+/**
+ * Add a capture file event callback.
+ *
+ * @param func The function to be called for each event.
+ *             The function will be passed three parameters: The event type (event),
+ *             event-dependent data (data), and user-supplied data (user_data).
+ *             Event-dependent data may be a capture_file pointer, character pointer,
+ *             or NULL.
+ * @param user_data User-supplied data to pass to the callback. May be NULL.
+ */
+
 extern void
 cf_callback_add(cf_callback_t func, gpointer user_data);
 
+/**
+ * Remove a capture file event callback.
+ *
+ * @param func The function to be removed.
+ * @param user_data User-supplied data. Must be the same value supplied to cf_callback_add.
+ */
+
 extern void
-cf_callback_remove(cf_callback_t func);
+cf_callback_remove(cf_callback_t func, gpointer user_data);
 
 /**
  * Open a capture file.
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
  * Read all packets of a capture file into the internal structures.
  *
  * @param cf the capture file to be read
* @param from_save reread asked from cf_save_packets
  * @return one of cf_read_status_t
  */
 cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
 
 /**
* Read the pseudo-header and raw data for a packet.  It will pop
  * up an alert box if there's an error.
  *
* @param cf the capture file from which to read the packet
* @param fdata the frame_data structure for the packet in question
  * @param phdr pointer to a wtap_pkthdr structure to contain the
* packet's pseudo-header and other metadata
* @param buf a Buffer into which to read the packet's raw data
  * @return TRUE if the read succeeded, FALSE if there was an error
  */
-gboolean cf_read_frame_r(capture_file *cf, const frame_data *fdata,
-                         struct wtap_pkthdr *phdr, Buffer *buf);
+gboolean cf_read_record_r(capture_file *cf, const frame_data *fdata,
+                          struct wtap_pkthdr *phdr, Buffer *buf);
 
 /**
* Read the pseudo-header and raw data for a packet into a
* capture_file structure's pseudo_header and buf members.
  * It will pop up an alert box if there's an error.
  *
* @param cf the capture file from which to read the packet
* @param fdata the frame_data structure for the packet in question
  * @return TRUE if the read succeeded, FALSE if there was an error
  */
-gboolean cf_read_frame(capture_file *cf, frame_data *fdata);
+gboolean cf_read_record(capture_file *cf, frame_data *fdata);
 
 /**
  * Read packets from the "end" of a capture file.
@@ -239,7 +259,7 @@ gboolean cf_has_unsaved_data(capture_file *cf);
  * current capture file
  * @return one of cf_write_status_t
  */
-cf_write_status_t cf_save_packets(capture_file * cf, const char *fname,
+cf_write_status_t cf_save_records(capture_file * cf, const char *fname,
                                   guint save_format, gboolean compressed,
                                   gboolean discard_comments,
                                   gboolean dont_reopen);
@@ -297,14 +317,6 @@ const gchar *cf_get_tempfile_source(capture_file *cf);
  */
 int cf_get_packet_count(capture_file *cf);
 
-/**
- * Set the number of packets in the capture file.
- *
- * @param cf the capture file
- * @param packet_count the number of packets in the capture file
- */
-void cf_set_packet_count(capture_file *cf, int packet_count);
-
 /**
  * Is this capture file a temporary file?
  *
@@ -408,9 +420,11 @@ void cf_timestamp_auto_precision(capture_file *cf);
  *
  * @param cf the capture file
  * @param print_args the arguments what and how to print
+ * @param show_progress_bar TRUE if a progress bar is to be shown
  * @return one of cf_print_status_t
  */
-cf_print_status_t cf_print_packets(capture_file *cf, print_args_t *print_args);
+cf_print_status_t cf_print_packets(capture_file *cf, print_args_t *print_args,
+                                   gboolean show_progress_bar);
 
 /**
  * Print (export) the capture file into PDML format.
@@ -448,6 +462,15 @@ cf_print_status_t cf_write_csv_packets(capture_file *cf, print_args_t *print_arg
  */
 cf_print_status_t cf_write_carrays_packets(capture_file *cf, print_args_t *print_args);
 
+/**
+ * Print (export) the capture file into JSON format.
+ *
+ * @param cf the capture file
+ * @param print_args the arguments what and how to export
+ * @return one of cf_print_status_t
+ */
+cf_print_status_t cf_write_json_packets(capture_file *cf, print_args_t *print_args);
+
 /**
  * Find packet with a protocol tree item that contains a specified text string.
  *
@@ -673,9 +696,26 @@ gboolean cf_set_user_packet_comment(capture_file *cf, frame_data *fd, const gcha
  */
 guint32 cf_comment_types(capture_file *cf);
 
-#if defined(HAVE_HEIMDAL_KERBEROS) || defined(HAVE_MIT_KERBEROS)
-WS_DLL_PUBLIC
-void read_keytab_file(const char *);
+/**
+ * Add a resolved address to this file's list of resolved addresses.
+ *
+ * @param cf the capture file
+ * @param addr a string representing an IPv4 or IPv6 address
+ * @param name a string containing a name corresponding to that address
+ * @return TRUE if it succeeds, FALSE if not
+ */
+gboolean cf_add_ip_name_from_string(capture_file *cf, const char *addr, const char *name);
+
+#ifdef WANT_PACKET_EDITOR
+/**
+ * Give a frame new, edited data.
+ *
+ * @param cf the capture file
+ * @param fd frame_data structure for the frame
+ * @param phdr the struct wtap_pkthdr for the frame
+ * @param pd the raw packet data for the frame
+ */
+void cf_set_frame_edited(capture_file *cf, frame_data *fd, struct wtap_pkthdr *phdr, guint8 *pd);
 #endif
 
 #ifdef __cplusplus
@@ -683,3 +723,16 @@ void read_keytab_file(const char *);
 #endif /* __cplusplus */
 
 #endif /* file.h */
+
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 4
+ * tab-width: 8
+ * indent-tabs-mode: nil
+ * End:
+ *
+ * vi: set shiftwidth=4 tabstop=8 expandtab:
+ * :indentSize=4:tabSize=8:noTabs=true:
+ */
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
  *
  * @param cf the capture file to be read
- * @param from_save reread asked from cf_save_packets
+ * @param from_save reread asked from cf_save_records
  * @return one of cf_read_status_t
  */
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
 
 /**
- * Read the pseudo-header and raw data for a packet.  It will pop
+ * Read the metadata and raw data for a record.  It will pop
  * up an alert box if there's an error.
  *
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
  * up an alert box if there's an error.
  *
- * @param cf the capture file from which to read the packet
- * @param fdata the frame_data structure for the packet in question
+ * @param cf the capture file from which to read the record
+ * @param fdata the frame_data structure for the record in question
  * @param phdr pointer to a wtap_pkthdr structure to contain the
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
  * @param phdr pointer to a wtap_pkthdr structure to contain the
- * packet's pseudo-header and other metadata
- * @param buf a Buffer into which to read the packet's raw data
+ * record's metadata
+ * @param buf a Buffer into which to read the record's raw data
  * @return TRUE if the read succeeded, FALSE if there was an error
  */
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
 
 /**
- * Read the pseudo-header and raw data for a packet into a
- * capture_file structure's pseudo_header and buf members.
+ * Read the metadata and raw data for a record into a
+ * capture_file structure's phdr and buf members.
  * It will pop up an alert box if there's an error.
  *
@@ -131,35 +151,35 @@ void cf_reload(capture_file *cf);
  * It will pop up an alert box if there's an error.
  *
- * @param cf the capture file from which to read the packet
- * @param fdata the frame_data structure for the packet in question
+ * @param cf the capture file from which to read the record
+ * @param fdata the frame_data structure for the record in question
  * @return TRUE if the read succeeded, FALSE if there was an error
  */